==> cxf-testutils-2.0.6.11-fuse-sources.jar: org/apache/type_test/types3/RecInnerType.java <==

package org.apache.type_test.types3;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for RecInnerType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="RecInnerType">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="varInt" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *         &lt;element ref="{http://apache.org/type_test/types3}RecMostInner" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element ref="{http://apache.org/type_test/types3}RecInnerNext"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RecInnerType", propOrder = {
    "varInt",
    "recMostInner",
    "recInnerNext"
})
public class RecInnerType {

    @XmlElement(namespace = "http://apache.org/type_test/types3")
    protected int varInt;
    @XmlElement(name = "RecMostInner", namespace = "http://apache.org/type_test/types3", required = true)
    protected List<RecMostInnerType> recMostInner;
    @XmlElement(name = "RecInnerNext", namespace = "http://apache.org/type_test/types3", required = true)
    protected RecInnerNextType recInnerNext;

    /**
     * Gets the value of the varInt property.
     * 
     */
    public int getVarInt() {
        return varInt;
    }

    /**
     * Sets the value of the varInt property.
     * 
     */
    public void setVarInt(int value) {
        this.varInt = value;
    }

    /**
     * Gets the value of the recMostInner property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the recMostInner property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getRecMostInner().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link RecMostInnerType }
     * 
     * 
     */
    public List<RecMostInnerType> getRecMostInner() {
        if (recMostInner == null) {
            recMostInner = new ArrayList<RecMostInnerType>();
        }
        return this.recMostInner;
    }

    /**
     * Gets the value of the recInnerNext property.
     * 
     * @return
     *     possible object is
     *     {@link RecInnerNextType }
     *     
     */
    public RecInnerNextType getRecInnerNext() {
        return recInnerNext;
    }

    /**
     * Sets the value of the recInnerNext property.
     * 
     * @param value
     *     allowed object is
     *     {@link RecInnerNextType }
     *     
     */
    public void setRecInnerNext(RecInnerNextType value) {
        this.recInnerNext = value;
    }

}

==> cxf-testutils-2.1.3.18-fuse-sources.jar: org/apache/type_test/types3/RecInnerType.java <==

package org.apache.type_test.types3;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for RecInnerType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="RecInnerType">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="varInt" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *         &lt;element ref="{http://apache.org/type_test/types3}RecMostInner" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element ref="{http://apache.org/type_test/types3}RecInnerNext"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RecInnerType", propOrder = {
    "varInt",
    "recMostInner",
    "recInnerNext"
})
public class RecInnerType {

    protected int varInt;
    @XmlElement(name = "RecMostInner")
    protected List<RecMostInnerType> recMostInner;
    @XmlElement(name = "RecInnerNext", required = true)
    protected RecInnerNextType recInnerNext;

    /**
     * Gets the value of the varInt property.
     * 
     */
    public int getVarInt() {
        return varInt;
    }

    /**
     * Sets the value of the varInt property.
     * 
     */
    public void setVarInt(int value) {
        this.varInt = value;
    }

    /**
     * Gets the value of the recMostInner property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the recMostInner property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getRecMostInner().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link RecMostInnerType }
     * 
     * 
     */
    public List<RecMostInnerType> getRecMostInner() {
        if (recMostInner == null) {
            recMostInner = new ArrayList<RecMostInnerType>();
        }
        return this.recMostInner;
    }

    /**
     * Gets the value of the recInnerNext property.
     * 
     * @return
     *     possible object is
     *     {@link RecInnerNextType }
     *     
     */
    public RecInnerNextType getRecInnerNext() {
        return recInnerNext;
    }

    /**
     * Sets the value of the recInnerNext property.
     * 
     * @param value
     *     allowed object is
     *     {@link RecInnerNextType }
     *     
     */
    public void setRecInnerNext(RecInnerNextType value) {
        this.recInnerNext = value;
    }

}
